@@ -74,7 +74,7 @@ void emboss_getoptions(char *pgm, int argc, char *argv[])
   writecont = false;
   reg = true;
 
-    embInitP (pgm, argc, argv,"PHYLIPNEW");
+  embInitPV(pgm, argc, argv,"PHYLIPNEW",VERSION);
 
     phylofreq = ajAcdGetFrequencies("infile");
     phylotrees = ajAcdGetTree("intreefile");
@@ -220,6 +220,7 @@ void contwithin()
         ssqcont[i][k] = 1.0;   /* if a within contrast */
     }
   }
+  free(sumphen);
   contno = 1;
 }  /* contwithin */
 
